pub struct AttachmentScanner {
pub command: String,
pub timeout_seconds: u64,
}Fields
command: StringOperator-provided executable. Spawned per attempt with the resolved path as a single argument; non-zero exit → reject.
timeout_seconds: u64Trait Implementations
Sourceimpl Clone for AttachmentScanner
impl Clone for AttachmentScanner
Sourcefn clone(&self) -> AttachmentScanner
fn clone(&self) -> AttachmentScanner
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachmentScanner
impl Debug for AttachmentScanner
Sourceimpl<'de> Deserialize<'de> for AttachmentScanner
impl<'de> Deserialize<'de> for AttachmentScanner
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AttachmentScanner
Sourceimpl JsonSchema for AttachmentScanner
impl JsonSchema for AttachmentScanner
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AttachmentScanner
impl PartialEq for AttachmentScanner
Sourceimpl Serialize for AttachmentScanner
impl Serialize for AttachmentScanner
impl StructuralPartialEq for AttachmentScanner