pub struct Budget {
pub daily_usd_limit: Option<f64>,
pub warn_threshold_pct: Option<u32>,
pub message_ttl_hours: Option<u32>,
pub per_project_usd_limit: BTreeMap<String, f64>,
}Fields
daily_usd_limit: Option<f64>warn_threshold_pct: Option<u32>message_ttl_hours: Option<u32>per_project_usd_limit: BTreeMap<String, f64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Budget
impl<'de> Deserialize<'de> for Budget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Budget
impl JsonSchema for Budget
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Budget
impl RefUnwindSafe for Budget
impl Send for Budget
impl Sync for Budget
impl Unpin for Budget
impl UnsafeUnpin for Budget
impl UnwindSafe for Budget