pub struct ProjectMeta {
pub id: String,
pub name: String,
pub cwd: PathBuf,
}Fields
id: Stringname: Stringcwd: PathBufTrait Implementations
Sourceimpl Clone for ProjectMeta
impl Clone for ProjectMeta
Sourcefn clone(&self) -> ProjectMeta
fn clone(&self) -> ProjectMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectMeta
impl Debug for ProjectMeta
Sourceimpl<'de> Deserialize<'de> for ProjectMeta
impl<'de> Deserialize<'de> for ProjectMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProjectMeta
impl JsonSchema for ProjectMeta
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProjectMeta
impl RefUnwindSafe for ProjectMeta
impl Send for ProjectMeta
impl Sync for ProjectMeta
impl Unpin for ProjectMeta
impl UnsafeUnpin for ProjectMeta
impl UnwindSafe for ProjectMeta