pub struct RateLimitHook {
pub name: String,
pub action: String,
pub to: Option<String>,
pub template: Option<String>,
pub url: Option<String>,
pub url_env: Option<String>,
pub method: Option<String>,
pub command: Vec<String>,
}Expand description
One named action that can run on a rate-limit hit.
action is one of:
wait— sleep untilresets_at(orfallback_wait_seconds).send— write a message into the mailbox;toandtemplaterequired.webhook— POST/GET tourl(orurl_env); the rate-limit row serializes as JSON in the body.run— execcommandwith placeholders substituted.
Placeholders in template and command arguments:
{agent}, {runtime}, {hit_at}, {resets_at}, {resets_at_local},
{raw_match}.
Fields
name: Stringaction: Stringto: Option<String>template: Option<String>url: Option<String>url_env: Option<String>method: Option<String>command: Vec<String>Trait Implementations
Sourceimpl Clone for RateLimitHook
impl Clone for RateLimitHook
Sourcefn clone(&self) -> RateLimitHook
fn clone(&self) -> RateLimitHook
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RateLimitHook
impl Debug for RateLimitHook
Sourceimpl<'de> Deserialize<'de> for RateLimitHook
impl<'de> Deserialize<'de> for RateLimitHook
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RateLimitHook
impl JsonSchema for RateLimitHook
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RateLimitHook
impl RefUnwindSafe for RateLimitHook
impl Send for RateLimitHook
impl Sync for RateLimitHook
impl Unpin for RateLimitHook
impl UnsafeUnpin for RateLimitHook
impl UnwindSafe for RateLimitHook