pub struct AttachmentScanner {
pub command: String,
pub timeout_seconds: u64,
}Fields
command: StringOperator-provided executable. Spawned per attempt with the resolved path as a single argument; non-zero exit → reject.
timeout_seconds: u64Trait Implementations
Sourceimpl Clone for AttachmentScanner
impl Clone for AttachmentScanner
Sourcefn clone(&self) -> AttachmentScanner
fn clone(&self) -> AttachmentScanner
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachmentScanner
impl Debug for AttachmentScanner
Sourceimpl<'de> Deserialize<'de> for AttachmentScanner
impl<'de> Deserialize<'de> for AttachmentScanner
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AttachmentScanner
impl PartialEq for AttachmentScanner
Sourcefn eq(&self, other: &AttachmentScanner) -> bool
fn eq(&self, other: &AttachmentScanner) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AttachmentScanner
impl Serialize for AttachmentScanner
impl Eq for AttachmentScanner
impl StructuralPartialEq for AttachmentScanner